==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserFactorWebProfile.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorWebProfile
 */
@JsonPropertyOrder({ UserFactorWebProfile.JSON_PROPERTY_CREDENTIAL_ID })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorWebProfile implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CREDENTIAL_ID = "credentialId";
    private String credentialId;

    public UserFactorWebProfile() {
    }

    public UserFactorWebProfile credentialId(String credentialId) {

        this.credentialId = credentialId;
        return this;
    }

    /**
     * ID for the Factor credential
     *
     * @return credentialId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "dade.murphy@example.com", value = "ID for the Factor credential")
    @JsonProperty(JSON_PROPERTY_CREDENTIAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getCredentialId() {
        return credentialId;
    }

    @JsonProperty(JSON_PROPERTY_CREDENTIAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCredentialId(String credentialId) {
        this.credentialId = credentialId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorWebProfile userFactorWebProfile = (UserFactorWebProfile) o;
        return Objects.equals(this.credentialId, userFactorWebProfile.credentialId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(credentialId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorWebProfile {\n");
        sb.append("    credentialId: ").append(toIndentedString(credentialId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserFactorWebProfile.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorWebProfile
 */
@JsonPropertyOrder({ UserFactorWebProfile.JSON_PROPERTY_CREDENTIAL_ID })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorWebProfile implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CREDENTIAL_ID = "credentialId";
    private String credentialId;

    public UserFactorWebProfile() {
    }

    public UserFactorWebProfile credentialId(String credentialId) {

        this.credentialId = credentialId;
        return this;
    }

    /**
     * ID for the Factor credential
     *
     * @return credentialId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "dade.murphy@example.com", value = "ID for the Factor credential")
    @JsonProperty(JSON_PROPERTY_CREDENTIAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getCredentialId() {
        return credentialId;
    }

    @JsonProperty(JSON_PROPERTY_CREDENTIAL_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCredentialId(String credentialId) {
        this.credentialId = credentialId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorWebProfile userFactorWebProfile = (UserFactorWebProfile) o;
        return Objects.equals(this.credentialId, userFactorWebProfile.credentialId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(credentialId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorWebProfile {\n");
        sb.append("    credentialId: ").append(toIndentedString(credentialId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
